@@ -373,6 +373,8 @@ private:
   char *interfaceChoicemasq;
   char *ruleaction;
   char *chainChoice;
+  char *state_modules;
+  char *state_definition;
   char *stateChoice;
   char *policyChoice;
   char *flagChoice;
