@@ -1,6 +1,6 @@
   /*
 
-  knetfilter v 2.0.4
+  knetfilter v 2.1.1
 
   Copyright (C) 2000 Luigi Genoni
   		     venom@DarkStar.sns.it
@@ -821,7 +821,8 @@ void knetfilter::probeInterface(KProcess *, char *data, int len) {
 
 };
 
-
+//this comes from something i did two years ago
+//about fetchnetmask, but what?
 void knetfilter::probeInterface2(KProcess *, char *data, int len) {
 
   if (len<0) {
@@ -848,6 +849,7 @@ void knetfilter::probeInterface2(KProcess *, char *data, int len) {
 
 };
 
+
 // menu widget choice interface
 void knetfilter::interfaceActivated(int index) {
 
@@ -952,15 +954,18 @@ void knetfilter::stateActivated(int index) {
     stateChoice = "nostate";
     break;
   case 1:
-    stateChoice = "INVALID";
+    stateChoice = "unclean";
     break;
   case 2:
-    stateChoice = "ESTABLISHED";
+    stateChoice = "INVALID";
     break;
   case 3:
-    stateChoice = "NEW";
+    stateChoice = "ESTABLISHED";
     break;
   case 4:
+    stateChoice = "NEW";
+    break;
+  case 5:
     stateChoice = "RELATED";
     break;
   };
